@@ -4,11 +4,21 @@ import argparse
 from .app import app
 from .version import __version__
 
+from youtube_dl.utils import YoutubeDLHandler, compat_urllib_request
+
 """
     A server for providing the app anywhere, no need for GAE
 """
 
 
+def setup_url_handlers():
+    opener = compat_urllib_request.build_opener( YoutubeDLHandler())
+    opener.addheaders =[]
+    compat_urllib_request.install_opener(opener)
+
+def setup():
+    setup_url_handlers()
+
 def main():
     desc = """
            The youtube-dl API server.
@@ -32,6 +42,8 @@ def main():
     if args.version:
         print(__version__)
         exit(0)
+    
+    setup()
     httpserver.serve(app, host='localhost', port=args.port)
 
 if __name__ == '__main__':
